@@ -23,7 +23,8 @@ function(keyword, omim.apiKey,
           dir.create(download.path )
        options(timeout = 300)
        if( !file.exists(paste(download.path,"hgnc_complete_set.txt.gz",sep="/")))
-           download.file(hgnc,paste(download.path,"hgnc_complete_set.txt.gz",sep="/"),method="auto")
+          # download.file(hgnc,paste(download.path,"hgnc_complete_set.txt.gz",sep="/"),method="auto")
+           curl_download(hgnc,paste(download.path,"hgnc_complete_set.txt.gz",sep="/"))
        hgnc <- paste(download.path,"hgnc_complete_set.txt.gz",sep="/")
     }
     if(substr(hgnc,nchar(hgnc)-1,nchar(hgnc)) == "gz"){
@@ -99,11 +100,11 @@ function(keyword, omim.apiKey,
           urls1 <- paste("http://api.omim.org/api/entry?mimNumber=",j,"&include=all&apiKey=",omim.apiKey,sep="")
           urls2 <- paste("http://api.europe.omim.org/api/entry?mimNumber=",j,"&include=all&apiKey=",omim.apiKey,sep="")
           urls3 <- paste("http://api.us-east.omim.org/api/entry?mimNumber=",j,"&include=all&apiKey=",omim.apiKey,sep="")
-          doc.try1 = try(doc <- xmlTreeParse(urls1,useInternalNodes = TRUE),silent =T)  
+          doc.try1 = try(doc <- xmlTreeParse(urls1,useInternalNodes = TRUE),silent = TRUE)  
           if(class(doc.try1)[1] == "try-error"){
-              doc.try2 = try(doc <- xmlTreeParse(urls2,useInternalNodes = TRUE),silent =T)  
+              doc.try2 = try(doc <- xmlTreeParse(urls2,useInternalNodes = TRUE),silent = TRUE)  
               if(class(doc.try2)[1] == "try-error"){
-                 doc.try3 = try(doc <- xmlTreeParse(urls3,useInternalNodes = TRUE),silent =T)
+                 doc.try3 = try(doc <- xmlTreeParse(urls3,useInternalNodes = TRUE),silent = TRUE)
                  if(class(doc.try3)[1] == "try-error"){
                       print("Note: Can not connect the OMIM API!")
                  }
